#ifndef DEFINES_H
 #define DEFINES_H
 #include "defines.h"
#endif

int unix_setup(void *gpw);
int unix_crypt(void *given_key,void *gtext, int textlen, int secureflg); /* 0 or 1 */
int shuffle(char deck[]);
